@@ -1,51 +1,96 @@
 """Module containing useful plotting tools."""
 
+import platform
 import os
 from subprocess import PIPE, Popen
 
 import numpy as np
-import vtk
 
 import pyvista
+from pyvista import _vtk
 from .theme import parse_color, rcParams
 
 
-def system_supports_plotting():
-    """Check if x server is running.
+# Track render window support and plotting
+SUPPORTS_OPENGL = None
+SUPPORTS_PLOTTING = None
 
-    Return
-    ------
+def supports_open_gl():
+    """Return if the system supports OpenGL."""
+    global SUPPORTS_OPENGL
+    if SUPPORTS_OPENGL is None:
+        ren_win = _vtk.vtkRenderWindow()
+        SUPPORTS_OPENGL = bool(ren_win.SupportsOpenGL())
+    return SUPPORTS_OPENGL
+
+
+def _system_supports_plotting():
+    """Check if the environment supports plotting on Windows, Linux, or Mac OS.
+
+    Returns
+    -------
     system_supports_plotting : bool
-        True when on Linux and running an xserver.  Returns None when
-        on a non-linux platform.
+        ``True`` when system supports plotting.
 
     """
-    try:
-        if os.environ['ALLOW_PLOTTING'].lower() == 'true':
+    if os.environ.get('ALLOW_PLOTTING', '').lower() == 'true':
+        return True
+
+    # Windows case
+    if os.name == 'nt':
+        # actually have to check here.  Somewhat expensive.
+        return supports_open_gl()
+
+    # mac case
+    if platform.system() == 'Darwin':
+        # check if finder available
+        proc = Popen(["pgrep", "-qx", "Finder"], stdout=PIPE, stderr=PIPE)
+        proc.communicate()
+        if proc.returncode == 0:
             return True
-    except KeyError:
-        pass
+
+        # display variable set, likely available
+        return 'DISPLAY' in os.environ
+
+    # Linux case
     try:
-        p = Popen(["xset", "-q"], stdout=PIPE, stderr=PIPE)
-        p.communicate()
-        return p.returncode == 0
-    except:
+        proc = Popen(["xset", "-q"], stdout=PIPE, stderr=PIPE)
+        proc.communicate()
+        return proc.returncode == 0
+    except OSError:
         return False
 
 
+def system_supports_plotting():
+    """Check if the environment supports plotting.
+
+    Returns
+    -------
+    system_supports_plotting : bool
+        ``True`` when system supports plotting.
+
+    """
+    global SUPPORTS_PLOTTING
+    if SUPPORTS_PLOTTING is None:
+        SUPPORTS_PLOTTING = _system_supports_plotting()
+
+    # always use the cached response
+    return SUPPORTS_PLOTTING
+
+
 def update_axes_label_color(axes_actor, color=None):
     """Set the axes label color (internale helper)."""
     if color is None:
         color = rcParams['font']['color']
     color = parse_color(color)
-    if isinstance(axes_actor, vtk.vtkAxesActor):
+    if isinstance(axes_actor, _vtk.vtkAxesActor):
         prop_x = axes_actor.GetXAxisCaptionActor2D().GetCaptionTextProperty()
         prop_y = axes_actor.GetYAxisCaptionActor2D().GetCaptionTextProperty()
         prop_z = axes_actor.GetZAxisCaptionActor2D().GetCaptionTextProperty()
         for prop in [prop_x, prop_y, prop_z]:
             prop.SetColor(color[0], color[1], color[2])
             prop.SetShadow(False)
-    elif isinstance(axes_actor, vtk.vtkAnnotatedCubeActor):
+    elif isinstance(axes_actor, _vtk.vtkAnnotatedCubeActor):
         axes_actor.GetTextEdgesProperty().SetColor(color)
 
     return
@@ -61,7 +106,7 @@ def create_axes_marker(label_color=None, x_color=None, y_color=None,
         y_color = rcParams['axes']['y_color']
     if z_color is None:
         z_color = rcParams['axes']['z_color']
-    axes_actor = vtk.vtkAxesActor()
+    axes_actor = _vtk.vtkAxesActor()
     axes_actor.GetXAxisShaftProperty().SetColor(parse_color(x_color))
     axes_actor.GetXAxisTipProperty().SetColor(parse_color(x_color))
     axes_actor.GetYAxisShaftProperty().SetColor(parse_color(y_color))
@@ -102,7 +147,7 @@ def create_axes_orientation_box(line_width=1, text_scale=0.366667,
         z_color = rcParams['axes']['z_color']
     if edge_color is None:
         edge_color = rcParams['edge_color']
-    axes_actor = vtk.vtkAnnotatedCubeActor()
+    axes_actor = _vtk.vtkAnnotatedCubeActor()
     axes_actor.SetFaceTextScale(text_scale)
     if xlabel is not None:
         axes_actor.SetXPlusFaceText(f"+{xlabel}")
@@ -149,17 +194,17 @@ def create_axes_orientation_box(line_width=1, text_scale=0.366667,
         face_colors = (face_colors * 255).astype(np.uint8)
         cube.cell_arrays['face_colors'] = face_colors
 
-        cube_mapper = vtk.vtkPolyDataMapper()
+        cube_mapper = _vtk.vtkPolyDataMapper()
         cube_mapper.SetInputData(cube)
         cube_mapper.SetColorModeToDirectScalars()
         cube_mapper.Update()
 
-        cube_actor = vtk.vtkActor()
+        cube_actor = _vtk.vtkActor()
         cube_actor.SetMapper(cube_mapper)
         cube_actor.GetProperty().BackfaceCullingOn()
         cube_actor.GetProperty().SetOpacity(opacity)
 
-        prop_assembly = vtk.vtkPropAssembly()
+        prop_assembly = _vtk.vtkPropAssembly()
         prop_assembly.AddPart(axes_actor)
         prop_assembly.AddPart(cube_actor)
         actor = prop_assembly
